==> haskell-hjsmin-0.2.1-89.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hjsmin
version:              0.2.1
visibility:           public
id:                   hjsmin-0.2.1-9d1IIY2TGaibeVa2Nr4Ar
key:                  hjsmin-0.2.1-9d1IIY2TGaibeVa2Nr4Ar
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  d78402f613576a368b98382774cd5653
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hjsmin
hs-libraries:         HShjsmin-0.2.1-9d1IIY2TGaibeVa2Nr4Ar
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    language-javascript-0.7.1.0-L1t9mnArY27CUAxkxkjIpZ text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.2.1-90-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hjsmin
version:              0.2.1
visibility:           public
id:                   hjsmin-0.2.1-DJkPitA070X2jhBSAPswR5
key:                  hjsmin-0.2.1-DJkPitA070X2jhBSAPswR5
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  e04742d93a8167eda9f9da5744ce4f73
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hjsmin
hs-libraries:         HShjsmin-0.2.1-DJkPitA070X2jhBSAPswR5
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    language-javascript-0.7.1.0-3hSRLd355ht8QienKzpynx text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
